@@ -79,10 +79,10 @@ def validate_api_name(ctx, param, value):
     """
     if value.isalnum():
         if not len(value) > 3 and len(value) < 16: 
-            message = "The project name must only contain letters and numbers (3-15 characters)"
+            message = "The api name must only contain letters and numbers (3-15 characters)"
             raise click.BadParameter(message)
     else:
-        message = "The project name must only contain letters and numbers (3-15 characters)"
+        message = "The api name must only contain letters and numbers (3-15 characters)"
         raise click.BadParameter(message)
     return value
 
@@ -236,4 +236,65 @@ def validate_api_url(ctx, param, value):
         if value in names_no_valid:
             message = f"La url '{value}' ya se encuentra registrada en el proyecto"
             raise click.BadParameter(message)
-        return value
\ No newline at end of file
+        return value
+
+def validate_graph_name(ctx, param, value):
+    """
+        Función que valida que nombre de graph este en formato correcto
+
+        Función que valida que el nombre de graph este con formato correcto,
+        es decir que solo sea alfanumérico
+
+        Parámetros:
+            ctx         [Click Object]  Contexto de click
+            param       [Click Option]  Parametro recibido
+            value       [String]        Valor recibido como parámetro
+        Retorno:
+            value       [String]        Valor recibido como parámetro
+        Excepciones:
+            click.BadParameter  [Raise] Mensaje de parámetro incorrecto
+    """
+    if value.isalnum():
+        if not len(value) > 3 and len(value) < 16: 
+            message = "The graph name must only contain letters and numbers (3-15 characters)"
+            raise click.BadParameter(message)
+    else:
+        message = "The graph name must only contain letters and numbers (3-15 characters)"
+        raise click.BadParameter(message)
+    
+    graph_version = ctx.params['version']
+    group_graph = ctx.params['group']
+    name_graph = value
+    try:
+        with open('springlabs_django.json') as file:
+            data = json.load(file)
+    except:
+        message = "Ocurrió un problema interno al leer archivo (springlabs_django.json)"
+        raise click.BadParameter(message)
+    else:
+        versions_detail = data['versions_detail']
+        names_no_valid = []
+        # Recorremos todas las versiones
+        for versions in versions_detail:
+            # Si la versión del ciclo es en donde vamos a insertar el graph
+            if versions['version'] == graph_version:
+                groups_detail = versions["groups_detail"]
+                # Recorremos todos los grupos de esa versión
+                for group_detail in groups_detail:
+                    # Si el grupo del ciclo es en donde vamos a insertar el graph
+                    if group_graph == group_detail['group']:
+                        graphs = group_detail['graph']
+                        # Recorremos todas las apis de ese grupo
+                        for graph in graphs:
+                            name = graph["graph_name"]
+                            name_no_valid = name.lower()
+                            # Agregamos a lista de names_no_valid los nombres de los graphs no validos
+                            names_no_valid.append(name_no_valid)
+        find = name_graph.lower()
+        # Si el nombre de nuestro graph ya se encuentra en el proyecto
+        if find in names_no_valid:
+            message = f"El nombre del graph '{name_graph}' ya se encuentra registrado en la aplicación"
+            raise click.BadParameter(message)
+        return value
+
+    return value
\ No newline at end of file
